==> nextcloud-12.0.2.tgz: nextcloud/apps/password_policy/l10n/de.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein",
    "Password needs to contain at least one lower and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten. ",
    "Password needs to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten. ",
    "Password needs to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen enthalten. ",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Das Passwort ist unter den 1.000.000 häufigsten Passwörtern. Bitte wähle ein anderes.",
    "Password policy" : "Passwort-Regeln",
    "Minimal length" : "Minimale Länge",
    "Forbid common passwords" : "Häufig verwendete Passwörter verbieten",
    "Enforce upper and lower case characters" : "Groß- und Kleinbuchstaben erzwingen",
    "Enforce numeric characters" : "Zahlen erzwingen",
    "Enforce special characters" : "Sonderzeichen erzwingen",
    "Password need to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein",
    "Password need to contain at least one lower case character and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten.",
    "Password need to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten.",
    "Password need to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Das Passwort ist unter den 1.000.000 der häufigsten Passwörtern. Bitte wähle ein anderes Passwort."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/password_policy/l10n/de.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein",
    "Password needs to contain at least one lower and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten. ",
    "Password needs to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten. ",
    "Password needs to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten. ",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Das Passwort ist unter den 1.000.000 häufigsten Passwörtern. Bitte wähle ein anderes.",
    "Password is present in compromised password list. Please choose a different password." : "Das Passwort ist in der Liste der kompromittierten Passwörter enthalten. Bitte wähle ein anderes Passwort. ",
    "Password policy" : "Passwort-Regeln",
    "Minimal length" : "Minimale Länge",
    "Forbid common passwords" : "Häufig verwendete Passwörter verbieten",
    "Enforce upper and lower case characters" : "Groß- und Kleinbuchstaben erzwingen",
    "Enforce numeric characters" : "Zahlen erzwingen",
    "Enforce special characters" : "Sonderzeichen erzwingen",
    "Check password against the list of breached passwords from haveibeenpwnd.com" : "Das Passwort gegen eine Liste von geknackten Passwörtern bei haveibeenpwnd.com prüfen.",
    "Password need to be at least %s characters long" : "Das Passwort muss mindestens %s Zeichen lang sein",
    "Password need to contain at least one lower case character and one upper case character." : "Das Passwort muss mindestens einen Klein- und einen Großbuchstaben beinhalten.",
    "Password need to contain at least one numeric character." : "Das Passwort muss mindestens eine Zahl beinhalten.",
    "Password need to contain at least one special character." : "Das Passwort muss mindestens ein Sonderzeichen beinhalten.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Das Passwort ist unter den 1.000.000 der häufigsten Passwörtern. Bitte wähle ein anderes Passwort."
},
"nplurals=2; plural=(n != 1);");
